@@ -33,7 +33,7 @@ Archive::SevenZip - Read/write 7z , zip , ISO9960 and other archives
 =cut
 
 use vars qw(%sevenzip_charsetname %class_defaults $VERSION @EXPORT_OK %EXPORT_TAGS);
-$VERSION= '0.04';
+$VERSION= '0.05';
 
 # Archive::Zip API
 # Error codes
@@ -93,12 +93,15 @@ sub find_7z_executable {
     my $envsep = $^O =~ /MSWin/ ? ';' : ':';
     my @search = split /$envsep/, $ENV{PATH};
     if( $^O =~ /MSWin/i ) {
-        push @search, map { "$_\\7-Zip" } ($ENV{'ProgramFiles'}, $ENV{'ProgramFiles(x86)'});
+        push @search, map { "$_\\7-Zip" } grep {defined} ($ENV{'ProgramFiles'}, $ENV{'ProgramFiles(x86)'});
     };
     my $found = $class->version;
 
     while( ! defined $found and @search) {
         my $dir = shift @search;
+        if ($^O eq 'MSWin32') {
+            next unless -e file("$dir", "7z.exe" );
+        }
         $class_defaults{'7zip'} = "" . file("$dir", "7z" );
         $found = $class->version;
     };
